@@ -1,14 +1,18 @@
 """The VICC library for normalizing genes."""
+from .version import __version__  # noqa: F401
 from pathlib import Path
 import logging
 from os import environ
 
-from .version import __version__  # noqa: F401
-
 APP_ROOT = Path(__file__).resolve().parents[0]
 
+if "GENE_NORM_EB_PROD" in environ:
+    LOG_FN = "/tmp/gene.log"
+else:
+    LOG_FN = "gene.log"
+
 logging.basicConfig(
-    filename="gene.log",
+    filename=LOG_FN,
     format="[%(asctime)s] - %(name)s - %(levelname)s : %(message)s")
 logger = logging.getLogger("gene")
 logger.setLevel(logging.DEBUG)
@@ -18,13 +22,17 @@ logging.getLogger("boto3").setLevel(logging.INFO)
 logging.getLogger("botocore").setLevel(logging.INFO)
 logging.getLogger("urllib3").setLevel(logging.INFO)
 logging.getLogger("python_jsonschema_objects").setLevel(logging.INFO)
-logging.getLogger("biocommons.seqrepo.seqaliasdb.seqaliasdb").setLevel(logging.INFO)  # noqa: E501
-logging.getLogger("biocommons.seqrepo.fastadir.fastadir").setLevel(logging.INFO)  # noqa: E501
+logging.getLogger("biocommons.seqrepo.seqaliasdb.seqaliasdb").setLevel(logging.INFO)
+logging.getLogger("biocommons.seqrepo.fastadir.fastadir").setLevel(logging.INFO)
+
+if "GENE_NORM_EB_PROD" in environ:
+    ch = logging.StreamHandler()
+    ch.setLevel(logging.INFO)
+    logger.addHandler(ch)
 
 
-SEQREPO_ROOT_DIR = Path(
-    environ.get("SEQREPO_ROOT_DIR", "/usr/local/share/seqrepo/latest")
-)
+SEQREPO_DATA_PATH = environ.get("SEQREPO_DATA_PATH",
+                                "/usr/local/share/seqrepo/latest")
 
 
 class DownloadException(Exception):
@@ -35,8 +43,8 @@ class DownloadException(Exception):
         super().__init__(*args, **kwargs)
 
 
-from gene.schemas import SourceName, NamespacePrefix, SourceIDAfterNamespace, RefType  # noqa: E402, E501
-ITEM_TYPES = {k.lower(): v.value for k, v in RefType.__members__.items()}
+from gene.schemas import SourceName, NamespacePrefix, SourceIDAfterNamespace, ItemTypes  # noqa: E402, E501
+ITEM_TYPES = {k.lower(): v.value for k, v in ItemTypes.__members__.items()}
 
 # Sources we import directly (HGNC, Ensembl, NCBI)
 SOURCES = {source.value.lower(): source.value
@@ -56,3 +64,8 @@ PREFIX_LOOKUP = {v.value: SourceName[k].value
 NAMESPACE_LOOKUP = {v.value.lower(): NamespacePrefix[k].value
                     for k, v in SourceIDAfterNamespace.__members__.items()
                     if v.value != ""}
+
+from gene.etl import NCBI, HGNC, Ensembl  # noqa: E402, F401
+# used to get source class name from string
+SOURCES_CLASS = \
+    {s.value.lower(): eval(s.value) for s in SourceName.__members__.values()}
